@@ -46,7 +46,7 @@ class NbaPlayerModel(TypedDict):
     lastName: str
     teamId: NotRequired[str]
     team: NotRequired[NbaPlayerTeamInfo]
-    teamUpdateDate: NotRequired[str]
+    teamDate: NotRequired[str]
     stats: NotRequired[NbaPlayerStatInfo]
     cost: NotRequired[int]
     costComputationDate: NotRequired[str]
